@@ -36,6 +36,9 @@ class LPMain:
     def init_objects(self):
         self.obj_lst:list[LPObject] = [self]
         self.obj_lst.extend([value for value in vars(self).values() if isinstance(value,LPObject)])
+        for value in vars(self).values():
+            if isinstance(value,LPMain):
+                self.obj_lst.extend([v for v in vars(value).values() if isinstance(v,LPObject)])
         self.make_stateVarLst()
         self.def_pos()
         self.def_bounds()
